# -*- coding: utf-8 -*-

from django.conf.urls import include
from django.urls import path, re_path
from guichet import views as views_guichet
from doc import views as views_doc


urlpatterns = [
    re_path(r"^$", views_guichet.home, name="home"),
    re_path(r"^a-propos/$", views_doc.default_renderer, {"template_name": "doc/a-propos.html"}, name="a-propos"),
    re_path(r"^charte/$", views_doc.default_renderer, {"template_name": "doc/charte.html"}, name="charte"),
    re_path(r"^paypal_account/$", views_guichet.paypal_account_create, name="paypal-account"),
    re_path(r"^lydia_account/$", views_guichet.lydia_account_create, name="lydia-account"),
    re_path(r"^lydia_token/$", views_guichet.lydia_get_token, name="lydia-token"),
    re_path(r"^event_past/$", views_guichet.event_past_list, name="list-past-events"),
    re_path(r"^event/$", views_guichet.event_list, name="list-events"),
    re_path(r"^event/add/$", views_guichet.event_edit, name="add-event"),
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/$", views_guichet.event_details, name="show-event"),
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/archive/$", views_guichet.event_archived, name="archived-event"),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/purchase/$",
        views_guichet.ticket_purchase,
        name="purchase-ticket",
    ),
    # Administration des évènements
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/edit/$", views_guichet.event_edit, name="edit-event"),
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/delete/$", views_guichet.event_delete, name="delete-event"),
    # Administration des billets
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/$", views_guichet.ticket_list, name="list-tickets"),
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/add/$", views_guichet.ticket_add, name="add-ticket"),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/add/open/$",
        views_guichet.ticket_add,
        {"ticket_type": "open"},
        name="add-open-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/add/restricted/$",
        views_guichet.ticket_add,
        {"ticket_type": "restricted"},
        name="add-restricted-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/$",
        views_guichet.ticket_details,
        name="details-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/show_template/.*$",
        views_guichet.ticket_template,
        name="show-template-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/addinfo/$",
        views_guichet.infosup_edit,
        name="infosup-choices-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/addinfo/(?P<infos_type>[0-9]+)/$",
        views_guichet.infosup_edit,
        name="infosup-add-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/delinfo/(?P<infos_id>[0-9]+)/$",
        views_guichet.infosup_del,
        name="infosup-del-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/editinfo/(?P<infos_id>[0-9]+)/$",
        views_guichet.infosup_edit,
        name="infosup-edit-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/addoptalone/$",
        views_guichet.option_alone_edit,
        name="option-alone-add-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/deloptalone/(?P<option_id>[0-9]+)/$",
        views_guichet.option_alone_del,
        name="option-alone-del-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/editoptalone/(?P<option_id>[0-9]+)/$",
        views_guichet.option_alone_edit,
        name="option-alone-edit-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/addoptgroupe/$",
        views_guichet.option_group_edit,
        name="option-group-add-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/deloptgroupe/(?P<group_id>-?[0-9]+)/$",
        views_guichet.option_group_del,
        name="option-group-del-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/editoptgroupe/(?P<group_id>[0-9]+)/$",
        views_guichet.option_group_edit,
        name="option-group-edit-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/edit/$",
        views_guichet.ticket_edit,
        name="edit-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/delete/$",
        views_guichet.ticket_delete,
        name="delete-ticket",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/ticket/(?P<ticket_id>[0-9]+)/template/$",
        views_guichet.ticket_test_template,
        name="ticket_test_template",
    ),
    # Administration des réservations
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/paid/$",
        views_guichet.registration_list_paid,
        name="list-paid-registrations",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/unpaid/$",
        views_guichet.registration_list_unpaid,
        name="list-unpaid-registrations",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/download/$",
        views_guichet.registration_download,
        name="download-registrations",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/download-xlsx/$",
        views_guichet.get_event_xlsx,
        name="download-xlsx-registrations",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/download-targz/$",
        views_guichet.get_event_targz,
        name="download-targz-registrations",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/download-zip/$",
        views_guichet.get_event_zip,
        name="download-zip-registrations",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/choice/$",
        views_guichet.registration_choice,
        name="choice-registration",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/new/(?P<ticket_id>[0-9]+)$",
        views_guichet.registration_new,
        name="new-registration",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/(?P<registration_id>[0-9]+)/edit/$",
        views_guichet.registration_edit,
        name="registration-edit",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/(?P<registration_id>[0-9]+)/validate/$",
        views_guichet.registration_validate,
        name="validate-registration",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/(?P<registration_id>[0-9]+)/validate/"
        "(?P<payment_method>[0-9]+)$",
        views_guichet.registration_validate,
        name="validate-registration-method",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/(?P<registration_id>[0-9]+)/oppose/(?P<action>[a-z]+)/$",
        views_guichet.registration_oppose,
        name="oppose-registration",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/(?P<registration_id>[0-9]+)/email/$",
        views_guichet.registration_email,
        name="email-registration",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/check/$",
        views_guichet.registration_check,
        name="check-registration",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/registration/check_QR/$",
        views_guichet.registration_check_with_QR,
        name="check-registration-with-QR",
    ),
    path(
        "event/<slug:event_id>/registration/check/<uuid:registration_uuid>",
        views_guichet.registration_check_with_uuid,
        name="check-registration-with-uuid",
    ),
    # Stats
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/stats/$", views_guichet.stats, name="show-stats"),
    # Logs
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/logs/$", views_guichet.logs_list, name="show-logs"),
    # Managers
    re_path(r"^event/(?P<event_id>[0-9a-z-_]+)/managers/$", views_guichet.manager_list, name="list-managers"),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/managers/edituser/(?P<user_id>[0-9]+)/$",
        views_guichet.manager_list,
        name="edit-manager-user",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/managers/editclub/(?P<group_id>[0-9]+)/$",
        views_guichet.manager_list,
        name="edit-manager-group",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/managers/revokeuser/(?P<user_id>[0-9]+)/$",
        views_guichet.manager_revoke,
        name="revoke-manager-user",
    ),
    re_path(
        r"^event/(?P<event_id>[0-9a-z-_]+)/managers/revokeclub/(?P<group_id>[0-9]+)/$",
        views_guichet.manager_revoke,
        name="revoke-manager-group",
    ),
    # Gestion des ses propres réservations
    re_path(r"^registration/$", views_guichet.registration_list_self, name="list-self-registrations"),
    re_path(r"^registration/paypal/", include("paypal.standard.ipn.urls")),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/$", views_guichet.registration_details, name="show-registration"
    ),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/paypal-cancel/$",
        views_guichet.registration_paypal_cancel,
        name="paypal-cancel-registration",
    ),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/paypal-return/$",
        views_guichet.registration_paypal_return,
        name="paypal-return-registration",
    ),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/send-mail/$",
        views_guichet.registration_mail,
        name="mail-registration",
    ),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/billet.(?P<format>[\w]+)$",
        views_guichet.registration_print,
        name="print-registration",
    ),  # pas de « / » final
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/cancel/$",
        views_guichet.registration_cancel,
        name="cancel-registration",
    ),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/info-file/(?P<info_sup_id>[0-9]+)/.*$",
        views_guichet.access_info_sup_file,
        name="access-info-sup-file",
    ),
    re_path(
        r"^registration/(?P<registration_id>[0-9]+)/lydia-payment",
        views_guichet.lydia_init_payment,
        name="lydia-payment",
    ),
    # protected media was redirect to the correct path
    re_path(r"^media/protected/(?P<path>.+)$", views_guichet.manage_protected_file, name="manage_protected_file"),
    re_path(r"^protected/(?P<path>.+)$", views_guichet.manage_protected_file, name="manage_protected_file2"),
    path("webhook/lydia-confirm", views_guichet.lydia_webhook_confirm, name="lydia-webhook-confirm"),
]
